@@ -20,12 +20,12 @@ def create_footballdata_team_model(
     dt: datetime.datetime,
     name: str,
     full_time_goals: str,
-    shots: str,
-    shots_on_target: str,
-    fouls: str,
-    yellow_cards: str,
-    red_cards: str,
-    odds: str,
+    shots: str | None,
+    shots_on_target: str | None,
+    fouls: str | None,
+    yellow_cards: str | None,
+    red_cards: str | None,
+    odds: str | None,
     version: str,
 ) -> TeamModel:
     """Create a team model based off footballdata."""
@@ -34,7 +34,7 @@ def create_footballdata_team_model(
         name=name,
         location=None,
         players=[],
-        odds=[create_footballdata_odds_model(odds=odds)],
+        odds=[create_footballdata_odds_model(odds=odds)] if odds is not None else [],
         points=int(full_time_goals),
         ladder_rank=None,
         news=create_google_news_models(name, session, dt, league),
@@ -99,13 +99,13 @@ def create_footballdata_team_model(
         shots_headed=None,
         shots_off_target=None,
         shots_on_post=None,
-        shots_on_target=int(shots_on_target),
+        shots_on_target=int(shots_on_target) if shots_on_target is not None else None,
         through_ball_percentage=None,
         total_crosses=None,
         total_goals=None,
         total_long_balls=None,
         total_passes=None,
-        total_shots=int(shots),
+        total_shots=int(shots) if shots is not None else None,
         total_through_balls=None,
         draws=None,
         sub_outs=None,
@@ -115,7 +115,7 @@ def create_footballdata_team_model(
         win_percentage=None,
         wins=None,
         won_corners=None,
-        yellow_cards=int(yellow_cards),
+        yellow_cards=int(yellow_cards) if yellow_cards is not None else None,
         clean_sheet=None,
         crosses_caught=None,
         goals_conceded=None,
@@ -161,7 +161,7 @@ def create_footballdata_team_model(
         minutes=None,
         own_goals=None,
         pass_percentage=None,
-        red_cards=int(red_cards),
+        red_cards=int(red_cards) if red_cards is not None else None,
         starts=None,
         sub_ins=None,
         pitch_count=None,
@@ -369,7 +369,7 @@ def create_footballdata_team_model(
         largest_lead=None,
         disqualifications=None,
         flagrant_fouls=None,
-        fouls=int(fouls),
+        fouls=int(fouls) if fouls is not None else None,
         ejections=None,
         technical_fouls=None,
         vorp=None,
