@@ -150,6 +150,39 @@ NFL_TEAM_IDENTITY_MAP = {
     "Washington Football Team": WASHINGTON_COMMANDERS,
     "Las Vegas Raiders": LAS_VEGAS_RAIDERS,
     "Washington Commanders": WASHINGTON_COMMANDERS,
+    # NFL.com
+    "chiefs": KANSAS_CITY_CHIEFS,
+    "jaguars": JACKSONVILLE_JAGUARS,
+    "patriots": NEW_ENGLAND_PATRIOTS,
+    "bills": BUFFALO_BILLS,
+    "commanders": WASHINGTON_COMMANDERS,
+    "chargers": LOS_ANGELES_CHARGERS,
+    "lions": DETROIT_LIONS,
+    "bengals": CINCINATTI_BENGALS,
+    "buccaneers": TAMPA_BAY_BUCCANEERS,
+    "seahawks": SEATTLE_SEAHAWKS,
+    "titans": TENNESSEE_TITANS,
+    "cardinals": ARIZONA_CARDINALS,
+    "broncos": DENVER_BRONCOS,
+    "eagles": PHILADELPHIA_EAGLES,
+    "cowboys": DALLAS_COWBOYS,
+    "jets": NEW_YORK_JETS,
+    "giants": NEW_YORK_GIANTS,
+    "saints": NEW_ORLEANS_SAINTS,
+    "raiders": LAS_VEGAS_RAIDERS,
+    "colts": INDIANAPOLIS_COLTS,
+    "dolphins": MIAMI_DOLPHINS,
+    "panthers": CAROLINA_PANTHERS,
+    "texans": HOUSTAN_TEXANS,
+    "ravens": BALTIMORE_RAVENS,
+    "vikings": MINNESOTA_VIKINGS,
+    "browns": CLEVELAND_BROWNS,
+    "49ers": SAN_FRANCISCO_49ERS,
+    "rams": LOS_ANGELES_RAMS,
+    "steelers": PITTSBURGH_STEALERS,
+    "packers": GREEN_BAY_PACKERS,
+    "falcons": ATLANTA_FALCONS,
+    "bears": CHICAGO_BEARS,
 }
 EMPOWER_FIELD = "18784"
 TOM_BENSOM_HALL_OF_FAME_STADIUM = "28739"
@@ -382,6 +415,28 @@ NFL_VENUE_IDENTITY_MAP = {
     "1353": SANTIAGO_BERNABEU,
     "7696": OLYMPIC_STADIUM_BERLIN,
     "4737": CROKE_PARK,
+    # NBA.com
+    "EVERBANK STADIUM": EVERBANK_STADIUM,
+    "HIGHMARK STADIUM": HIGHMARK_STADIUM,
+    "SOFI STADIUM": SOFI_STADIUM,
+    "PAYCOR STADIUM": PAYCOR_STADIUM,
+    "LUMEN FIELD": LUMEN_FIELD,
+    "STATE FARM STADIUM": STATE_FARM_STADIUM,
+    "LINCOLN FINANCIAL FIELD": LINCOLN_FINANCIAL_FIELD,
+    "METLIFE STADIUM": METLIFE_STADIUM,
+    "CAESARS SUPERDOME": CAESARS_SUPERDOME,
+    "LUCAS OIL STADIUM": LUCAS_OIL_STADIUM,
+    "BANK OF AMERICA STADIUM": BANK_OF_AMERICA_STADIUM,
+    "M&T BANK STADIUM": MTT_BANK_STADIUM,
+    "TOTTENHAM HOTSPUR STADIUM": TOTTENHAM_HOTSPUR_STADIUM,
+    "HARD ROCK STADIUM": HARD_ROCK_STADIUM,
+    "ACRISURE STADIUM": ACRISURE_STADIUM,
+    "ALLEGIANT STADIUM": ALLEGIANT_STADIUM,
+    "RAYMOND JAMES STADIUM": RAYMOND_JAMES_STADIUM,
+    "LAMBEAU FIELD": LAMBEAU_FIELD,
+    "GEHA FIELD AT ARROWHEAD STADIUM": ARROWHEAD_STADIUM,
+    "MERCEDES-BENZ STADIUM": MERCEDEZ_BENZ_STADIUM,
+    "NORTHWEST STADIUM": FEDEX_FIELD,
 }
 NFL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
