@@ -41,8 +41,8 @@ def _create_tennisdata_game_model(
     loser_points_set_5: str | None,
     winner_sets: str | None,
     loser_sets: str | None,
-    winner_odds: str,
-    loser_odds: str,
+    winner_odds: str | None,
+    loser_odds: str | None,
     session: ScrapeSession,
     league: League,
     version: str,
@@ -157,8 +157,8 @@ def _cached_create_tennisdata_game_model(
     loser_points_set_5: str | None,
     winner_sets: str | None,
     loser_sets: str | None,
-    winner_odds: str,
-    loser_odds: str,
+    winner_odds: str | None,
+    loser_odds: str | None,
     session: ScrapeSession,
     league: League,
     version: str,
@@ -219,8 +219,8 @@ def create_tennisdata_game_model(
     loser_points_set_5: str | None,
     winner_sets: str | None,
     loser_sets: str | None,
-    winner_odds: str,
-    loser_odds: str,
+    winner_odds: str | None,
+    loser_odds: str | None,
     session: ScrapeSession,
     league: League,
 ) -> GameModel:
